@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2018 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2020 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -153,7 +153,6 @@ public:
   QAction *shareMenuAct_;
   QAction *emailShareAct_;
   QAction *evernoteShareAct_;
-  QAction *gplusShareAct_;
   QAction *facebookShareAct_;
   QAction *livejournalShareAct_;
   QAction *pocketShareAct_;
@@ -227,6 +226,8 @@ public:
   bool notDeleteStarred_;
   bool notDeleteLabeled_;
   bool markIdenticalNewsRead_;
+  bool avoidOldNews_;
+  QDate avoidedOldNewsDate_;
 
   bool autoLoadImages_;
   bool openLinkInBackground_;
@@ -566,6 +567,7 @@ private:
   QAction *layoutToggle_;
   QAction *systemStyle_;
   QAction *system2Style_;
+  QAction *darkStyle_;
   QAction *greenStyle_;
   QAction *orangeStyle_;
   QAction *purpleStyle_;
