@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2018 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2020 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -109,16 +109,23 @@ void ParseObject::slotParse(const QByteArray &xmlData, const int &feedId,
 
   db_.transaction();
 
-  // extract feed id and duplicate news mode from feed table
+  // extract feed id, duplicate news mode and date to avoid from feed table
   parseFeedId_ = feedId;
   QString feedUrl;
   duplicateNewsMode_ = false;
+  addSingleNewsAnyDate_ = false;
+  avoidedOldSingleNews_ = false;
+  avoidedOldSingleNewsDate_ = QDate::currentDate();
   QSqlQuery q(db_);
   q.setForwardOnly(true);
-  q.exec(QString("SELECT duplicateNewsMode, xmlUrl FROM feeds WHERE id=='%1'").arg(parseFeedId_));
+  q.exec(QString("SELECT duplicateNewsMode, xmlUrl, addSingleNewsAnyDateOn, avoidedOldSingleNewsDateOn, avoidedOldSingleNewsDate"
+                 " FROM feeds WHERE id=='%1'").arg(parseFeedId_));
   if (q.first()) {
     duplicateNewsMode_ = q.value(0).toBool();
     feedUrl = q.value(1).toString();
+    addSingleNewsAnyDate_ = q.value(2).toBool();
+    avoidedOldSingleNews_ = q.value(3).toBool();
+    avoidedOldSingleNewsDate_ = q.value(4).toDate();
   }
 
   // id not found (ex. feed deleted while updating)
@@ -341,6 +348,11 @@ void ParseObject::parseAtom(const QString &feedUrl, const QDomDocument &doc)
     }
 
     newsItem.description = newsList.item(i).namedItem("summary").toElement().text();
+    QDomNode nodeSummary = newsList.item(i).namedItem("summary");
+    if (!nodeSummary.isNull() && newsItem.description.isEmpty()) {
+      QTextStream in(&newsItem.description);
+      nodeSummary.save(in, 0);
+    }
     QDomNode nodeContent = newsList.item(i).namedItem("content");
     if (nodeContent.toElement().attribute("type") == "xhtml") {
       QTextStream in(&newsItem.content);
@@ -453,8 +465,21 @@ void ParseObject::addAtomNewsIntoBase(NewsItemStruct *newsItem)
     if (isDuplicate) break;
   }
 
-  // if duplicates not found, add news into base
-  if (!isDuplicate) {
+  // Verify old news before a date to avoid adding them to base
+  bool isOld = false;
+  QDateTime pubDate_ = QDateTime::fromString(newsItem->updated, "yyyy-MM-ddTHH:mm:ss");
+  QDateTime avoidedDate_ = QDateTime(mainApp->mainWindow()->avoidedOldNewsDate_);
+  if (!addSingleNewsAnyDate_) {      //
+    if (avoidedOldSingleNews_ ) {     // avoid adding old single news
+      if (QDateTime(avoidedOldSingleNewsDate_) > pubDate_)
+        isOld = true;
+      } else if (mainApp->mainWindow()->avoidOldNews_ && avoidedDate_ > pubDate_) {   // avoid adding old news
+        isOld = true;
+      }
+   }
+
+  // if duplicates not found and is old news, add them into base
+  if (!isDuplicate && !isOld) {
     bool read = false;
     if (mainApp->mainWindow()->markIdenticalNewsRead_) {
       q.prepare("SELECT id FROM news WHERE title LIKE :title AND feedId!=:id");
@@ -602,7 +627,18 @@ void ParseObject::parseRss(const QString &feedUrl, const QDomDocument &doc)
     newsItem.link = url.toString();
 
     newsItem.description = newsList.item(i).namedItem("description").toElement().text();
+    QDomNode nodeSummary = newsList.item(i).namedItem("description");
+    if (!nodeSummary.isNull() && newsItem.description.isEmpty()) {
+      QTextStream in(&newsItem.description);
+      nodeSummary.save(in, 0);
+    }
     newsItem.content = newsList.item(i).namedItem("content:encoded").toElement().text();
+    QDomNode nodeContent = newsList.item(i).namedItem("content:encoded");
+    if (!nodeContent.isNull() && newsItem.content.isEmpty()) {
+      QTextStream in(&newsItem.content);
+      nodeContent.save(in, 0);
+    }
+
     if (newsItem.content.isEmpty() || (newsItem.description.length() > newsItem.content.length())) {
       newsItem.content.clear();
     } else {
@@ -720,8 +756,21 @@ void ParseObject::addRssNewsIntoBase(NewsItemStruct *newsItem)
     if (isDuplicate) break;
   }
 
-  // if duplicates not found, add news into base
-  if (!isDuplicate) {
+  // Verify old news before a date to avoid adding them to base
+  bool isOld = false;
+  QDateTime pubDate_ = QDateTime::fromString(newsItem->updated, "yyyy-MM-ddTHH:mm:ss");
+  QDateTime avoidedDate_ = QDateTime(mainApp->mainWindow()->avoidedOldNewsDate_);
+  if (!addSingleNewsAnyDate_) {      //
+    if (avoidedOldSingleNews_ ) {     // avoid adding old single news
+      if (QDateTime(avoidedOldSingleNewsDate_) > pubDate_)
+        isOld = true;
+      } else if (mainApp->mainWindow()->avoidOldNews_ && avoidedDate_ > pubDate_) {   // avoid adding old news
+              isOld = true;
+      }
+   }
+
+ // if duplicates not found And old news, add them into base
+ if (!isDuplicate && !isOld) {
     bool read = false;
     if (mainApp->mainWindow()->markIdenticalNewsRead_) {
       q.prepare("SELECT id FROM news WHERE title LIKE :title AND feedId!=:id");
@@ -888,10 +937,10 @@ QString ParseObject::parseDate(const QString &dateString, const QString &urlStri
 void ParseObject::runUserFilter(int feedId, int filterId)
 {
   QSqlQuery q(db_);
-  bool onlyNew = true;
+  bool isAllFilters = true;
 
   if (filterId != -1) {
-    onlyNew = false;
+    isAllFilters = false;
     q.exec(QString("SELECT enable, type FROM filters WHERE id='%1' AND feeds LIKE '%,%2,%'").
            arg(filterId).arg(feedId));
   } else {
@@ -900,9 +949,9 @@ void ParseObject::runUserFilter(int feedId, int filterId)
   }
 
   while (q.next()) {
-    if ((q.value(0).toInt() == 0) && onlyNew) continue;
+    if ((q.value(0).toInt() == 0) && isAllFilters) continue;
 
-    if (onlyNew)
+    if (isAllFilters)
       filterId = q.value(2).toInt();
     int filterType = q.value(1).toInt();
 
@@ -952,8 +1001,6 @@ void ParseObject::runUserFilter(int feedId, int filterId)
 
     whereStr = QString(" WHERE feedId='%1' AND deleted=0").arg(feedId);
 
-    if (onlyNew) whereStr.append(" AND new=1");
-
     qStr2.clear();
     switch (filterType) {
     case 1: // Match all conditions
